# GPAO Client

GPAO client, is a python client designed to make distributed computing.

## Installation
Create a Python environment :
```
ci/createEnv.sh
```

## Example
Note that you must install the GPAO server before on localhost (https://github.com/ign-packo/ign-gpao).
Then you can run the test :
```
ci/test.sh
```

## Linked projects

This project is used to create a JSON file that describe the set of tasks.

https://github.com/arnaudbirk/ign-gpao-project-builder


This project is the server used to orchestrate the taks.

https://github.com/ign-packo/ign-gpao


